<?xml version="1.0" encoding="UTF-8" ?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
  <xsl:output method="xml" version="1.0" encoding="utf-8" indent="yes"/>
  <xsl:template match="/">
    <DocumentObjects xmlns="urn:RevisableObjectImportTemplate.xsd">
      <xsl:apply-templates />
    </DocumentObjects>
  </xsl:template>
  
  <xsl:template match="test-results">
    <xsl:apply-templates select="//test-case" />    
  </xsl:template>
  
  <xsl:template match="test-case">
    <xsl:element name="DocumentObject" namespace="urn:RevisableObjectImportTemplate.xsd">
        <xsl:attribute name="ProjectName">NunitOutput</xsl:attribute>
        <xsl:attribute name="TypeName">NunitTest</xsl:attribute>
      <xsl:variable name="title">
        <xsl:call-template name="lastIndexOf">
          <xsl:with-param name="string" select="@name" />
          <xsl:with-param name="char" select="'.'" />
        </xsl:call-template>
      </xsl:variable>
        <xsl:attribute name="Title">
          <xsl:value-of select="$title" />
        </xsl:attribute>
      <xsl:attribute name="ID">
        <xsl:value-of select="@name" />
      </xsl:attribute>

      <xsl:attribute name="Disabled">false</xsl:attribute>

      <xsl:variable name="fullChapterPath">
        <xsl:call-template name="replace-string">
          <xsl:with-param name="text" select="@name"/>
          <xsl:with-param name="replace" select="'.'"/>
          <xsl:with-param name="with" select="'\'"/>
        </xsl:call-template>
      </xsl:variable>

      <xsl:variable name="backslash">\</xsl:variable>
      
      <xsl:variable name="titleWithDash">
        <xsl:value-of select="concat($backslash, $title)" />
      </xsl:variable>
      
      <xsl:attribute name="ChapterPath">
        <xsl:text>NunitTest\</xsl:text>
        <xsl:call-template name="replace-string">
          <xsl:with-param name="text" select="$fullChapterPath"/>
          <xsl:with-param name="replace" select="$titleWithDash"/>
          <xsl:with-param name="with" select="''"/>
        </xsl:call-template>
      </xsl:attribute>
      <xsl:element name="Attributes" namespace="urn:RevisableObjectImportTemplate.xsd">
        <xsl:element name="Attribute" namespace="urn:RevisableObjectImportTemplate.xsd">
          <xsl:attribute name="AttributeType">BoolAttribute</xsl:attribute>
          <xsl:attribute name="AttributeName">Success</xsl:attribute>

          <xsl:choose>
            <xsl:when test="string-length(normalize-space(@success))=0">False</xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="@success" />
            </xsl:otherwise>
          </xsl:choose>
          
        </xsl:element>
        <xsl:element name="Attribute" namespace="urn:RevisableObjectImportTemplate.xsd">
          <xsl:attribute name="AttributeType">BoolAttribute</xsl:attribute>
          <xsl:attribute name="AttributeName">Executed</xsl:attribute>

          <xsl:choose>
            <xsl:when test="string-length(normalize-space(@executed))=0">False</xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="@executed" />
            </xsl:otherwise>
          </xsl:choose>

         
        </xsl:element>
      </xsl:element>
      <xsl:element name="Traces" namespace="urn:RevisableObjectImportTemplate.xsd">    </xsl:element>
      <xsl:element name="IncomingTraces" namespace="urn:RevisableObjectImportTemplate.xsd">    </xsl:element>

    </xsl:element>
  </xsl:template>

  <xsl:template name="lastIndexOf">
    <!-- declare that it takes two parameters - the string and the char -->
    <xsl:param name="string" />
    <xsl:param name="char" />
    <xsl:choose>
      <!-- if the string contains the character... -->
      <xsl:when test="contains($string, $char)">
        <!-- call the template recursively... -->
        <xsl:call-template name="lastIndexOf">
          <!-- with the string being the string after the character
                 -->
          <xsl:with-param name="string"
                          select="substring-after($string, $char)" />
          <!-- and the character being the same as before -->
          <xsl:with-param name="char" select="$char" />
        </xsl:call-template>
      </xsl:when>
      <!-- otherwise, return the value of the string -->
      <xsl:otherwise>
        <xsl:value-of select="$string" />
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>


  <xsl:template name="replace-string">
    <xsl:param name="text"/>
    <xsl:param name="replace"/>
    <xsl:param name="with"/>
    <xsl:choose>
      <xsl:when test="contains($text,$replace)">
        <xsl:value-of select="substring-before($text,$replace)"/>
        <xsl:value-of select="$with"/>
        <xsl:call-template name="replace-string">
          <xsl:with-param name="text" select="substring-after($text,$replace)"/>
          <xsl:with-param name="replace" select="$replace"/>
          <xsl:with-param name="with" select="$with"/>
        </xsl:call-template>
      </xsl:when>
      <xsl:otherwise>
        <xsl:value-of select="$text"/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <!--<xsl:template match="@*" mode="rootRule">
    <xsl:variable name="leftBraceReplaced">
      <xsl:call-template name="replace-string">
        --><!-- imported template --><!--
        <xsl:with-param name="text" select="."/>
        <xsl:with-param name="replace" select="'{'"/>
        <xsl:with-param name="with" select="'{{'"/>
      </xsl:call-template>
    </xsl:variable>
    <xsl:variable name="bothBracesReplaced">
      <xsl:call-template name="replace-string">
        <xsl:with-param name="text" select="$leftBraceReplaced"/>
        <xsl:with-param name="replace" select="'}'"/>
        <xsl:with-param name="with" select="'}}'"/>
      </xsl:call-template>
    </xsl:variable>
    <xsl:attribute name="{name()}">
      <xsl:value-of select="$bothBracesReplaced"/>
    </xsl:attribute>
  </xsl:template>-->


  <!--<xsl:template match="test-case">
    <xsl:value-of select="position()" />
    <xsl:text>)</xsl:text>
    <xsl:value-of select="@name" />
    <xsl:text>:</xsl:text>
    <xsl:value-of select="child::node()/message" />
    <xsl:text disable-output-escaping="yes"></xsl:text>
    <xsl:if test="failure">
      <xsl:value-of select="failure/stack-trace" />
      <xsl:text />
    </xsl:if>
  </xsl:template>-->
</xsl:stylesheet>